@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 92 $
+# Revision: $Rev: 97 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -91,7 +91,6 @@ class RecordList(RecordListBase):
         self.connect( self.form, PYSIGNAL("modified()"), self.listViewRecord.onModified )    
         # currently not needed: 
         # self.connect( self.image, PYSIGNAL("modified()"), self.onModified )
-        
 
     #-- list interface ---------------------------------------------------------
     def add(self, rec):
@@ -176,8 +175,8 @@ if (__name__ == "__main__"):
     f = AMCFile33("Filme.amc", "rb")
     
     rec = f.read()
-    w.add( rec )
-    w.focusFirst()
+#    w.add( rec )
+#    w.focusFirst()
 
     a.setMainWidget(w)
     w.show()
