@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 83 $
+# Revision: $Rev: 93 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -35,7 +35,7 @@ from pprint import pformat
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 83 $
+# Revision: $Rev: 93 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -345,7 +345,7 @@ defaultScript = %(defaultScript)s
 class _Settings0(dict):
     """defines first element in configuration chain"""
     default = {
-        'logLevel': {'<none>'                : logging.DEBUG,
+        'logLevel': {'default'               : logging.DEBUG,
                      '__main__'              : logging.DEBUG,
                      'AbstractFile'          : logging.DEBUG,
                      'AMCFile33'             : logging.DEBUG,
@@ -355,12 +355,15 @@ class _Settings0(dict):
                      'IODeviceBuffer'        : logging.DEBUG,
                      'Language'              : logging.DEBUG,
                      'MediaInfo'             : logging.DEBUG,
+                     'MediaInfoDialog'       : logging.DEBUG,
                      'misc'                  : logging.DEBUG,
                      'PictureDialog'         : logging.DEBUG,
                      'PicturePreview'        : logging.DEBUG,
                      'RecordList'            : logging.DEBUG,
+                     'ListViewRecord'        : logging.DEBUG,
                      'RecordPreview'         : logging.DEBUG,
-                     'ScriptExecutionDialog' : logging.DEBUG,
+                     'ScriptExecDialog'      : logging.DEBUG,
+                     'StdIOProcess'          : logging.DEBUG,
                      'ScriptSelection'       : logging.DEBUG,
                      'Settings'              : logging.DEBUG,
                      'TitleMatchList'        : logging.DEBUG,
@@ -403,7 +406,7 @@ class _Settings0(dict):
                           'mediaType'       : u"CD-Rom",
                           'source'          : u"",
                           'borrower'        : u"",
-                          'discs'           : 1,
+                          'discs'           : 0,
                           'videoBitrate'    : 0,
                           'audioBitrate'    : 0,
                           'length'          : 0,
@@ -427,14 +430,14 @@ class _Settings0(dict):
         
         'embeddedImage': False,
         'imageFormat': 'JPEG',
-        'filenamePrefix': u"pictures/movies_%04d",
+        'filenamePrefix': u"pictures/movie_%04d",
         
         'sortColumn': 0,
         'zeroPrefix_patch': True,
         
         'scripts':{'[Merkosh Special]':
                    (u"all available fields from IMDB (US)\n+ medium sized picture from Amazon\n+ big picture from filmposter-archiv.de",
-                    [('IMDB-en.pl', 'originalTitle', 'year', 'picture', 'category', 'actors', 'rating', 'url', 'length', 'country', 'languages', 'description', 'comments', 'translatedTitle', 'producer'),
+                    [('IMDB-en.pl', 'originalTitle', 'year', 'picture', 'category', 'actors', 'rating', 'url', 'length', 'country', 'languages', 'description', 'comments', 'translatedTitle', 'producer', 'director'),
                      ('amazon-en.pl', 'picture'),
                      ('filmposterarchiv-de.pl', 'picture'), ]),
 
@@ -446,7 +449,7 @@ class _Settings0(dict):
                    
                    'IMDB':
                    (u"download all available fields from IMDB (US)",
-                    [('IMDB-en.pl', 'originalTitle', 'year', 'picture', 'category', 'actors', 'rating', 'url', 'length', 'country', 'languages', 'description', 'comments', 'translatedTitle', 'producer'),]
+                    [('IMDB-en.pl', 'originalTitle', 'year', 'picture', 'category', 'actors', 'rating', 'url', 'length', 'country', 'languages', 'description', 'comments', 'translatedTitle', 'producer', 'director'),]
                     ),
                    
                    'Amazon.com':
